@@ -101,7 +101,7 @@ init (NstPlugin *plugin)
 			type = MAILER_BALSA;
 		else if (strstr (mail_cmd, "thunder"))
 			type = MAILER_THUNDERBIRD;
-		else if (strstr (mail_cmd, "sylpheed"))
+		else if (strstr (mail_cmd, "sylpheed") || strstr (mail_cmd, "claws"))
 			type = MAILER_SYLPHEED;
 	}
 
@@ -266,24 +266,24 @@ get_thunderbird_mailto (GtkWidget *contact_widget, GString *mailto, GList *file_
 {
 	GList *l;
 
-	g_string_append (mailto, "-compose ");
+	g_string_append (mailto, "-compose \"");
 	if (email != NULL) {
 		if (name != NULL)
-			g_string_append_printf (mailto, "to=\""CONTACT_FORMAT"\",", name, email);
+			g_string_append_printf (mailto, "to='"CONTACT_FORMAT"',", name, email);
 		else
-			g_string_append_printf (mailto, "to=%s,", email);
+			g_string_append_printf (mailto, "to='%s',", email);
 	} else {
 		const char *text;
 
 		text = gtk_entry_get_text (GTK_ENTRY (contact_widget));
 		if (text != NULL && *text != '\0')
-			g_string_append_printf (mailto, "to=\"%s\",", text);
+			g_string_append_printf (mailto, "to='%s',", text);
 	}
 	g_string_append_printf (mailto,"attachment='%s", (char *)file_list->data);
 	for (l = file_list->next ; l; l=l->next){
 		g_string_append_printf (mailto,",%s", (char *)l->data);
 	}
-	g_string_append_c (mailto, '\'');
+	g_string_append (mailto, "'\"");
 }
 
 static void
@@ -294,17 +294,17 @@ get_sylpheed_mailto (GtkWidget *contact_widget, GString *mailto, GList *file_lis
 	g_string_append (mailto, "--compose ");
 	if (email != NULL) {
 		if (name != NULL)
-			g_string_append_printf (mailto, "\""CONTACT_FORMAT"\",", name, email);
+			g_string_append_printf (mailto, "\""CONTACT_FORMAT"\" ", name, email);
 		else
-			g_string_append_printf (mailto, "%s,", email);
+			g_string_append_printf (mailto, "%s ", email);
 	} else {
 		const char *text;
 
 		text = gtk_entry_get_text (GTK_ENTRY (contact_widget));
 		if (text != NULL && *text != '\0')
-			g_string_append_printf (mailto, "\"%s\",", text);
+			g_string_append_printf (mailto, "\"%s\" ", text);
 		else
-			g_string_append (mailto, " \"\"");
+			g_string_append (mailto, "\"\"");
 	}
 	g_string_append_printf (mailto,"--attach \"%s\"", (char *)file_list->data);
 	for (l = file_list->next ; l; l=l->next){
@@ -365,7 +365,7 @@ NstPluginInfo plugin_info = {
 	"evolution",
 	N_("Email"),
 	FALSE,
-	FALSE,
+	NAUTILUS_CAPS_NONE,
 	init,
 	get_contacts_widget,
 	NULL,
