@@ -28,22 +28,22 @@
 #include "config.h"
 
 #include <glib/gi18n-lib.h>
-#include <libgupnp-av/gupnp-av.h>
+#include <libgupnp/gupnp.h>
 #include "nautilus-sendto-plugin.h"
 
-#define MEDIA_SERVER "urn:schemas-upnp-org:device:MediaServer:*"
+#define MEDIA_SERVER "urn:schemas-upnp-org:device:MediaServer:1"
 #define CDS "urn:schemas-upnp-org:service:ContentDirectory"
 
 enum {
 	UDN_COL,
 	NAME_COL,
+	INTERFACE_COL,
 	NUM_COLS
 };
 
 static GtkWidget *combobox;
 static GtkTreeModel *model;
-static GUPnPContext *context;
-static GUPnPControlPoint *cp;
+static GUPnPContextManager *context_manager;
 
 static gboolean
 find_device (const gchar *udn,
@@ -90,8 +90,9 @@ get_introspection_cb (GUPnPServiceInfo *service_info,
 {
 	GUPnPDeviceInfo *device_info;
 	gchar *name;
-	const gchar *udn;
+	const gchar *udn, *interface;
 	GtkTreeIter iter;
+	GUPnPContext *context;
 
 	device_info = GUPNP_DEVICE_INFO (user_data);
 
@@ -115,9 +116,13 @@ get_introspection_cb (GUPnPServiceInfo *service_info,
 	if (name == NULL)
 		name = g_strdup (udn);
 
+	context = gupnp_device_info_get_context (device_info);
+	interface = gssdp_client_get_interface (GSSDP_CLIENT (context));
+
 	gtk_list_store_insert_with_values (GTK_LIST_STORE (model), NULL, -1,
 					   UDN_COL, udn,
 					   NAME_COL, name,
+					   INTERFACE_COL, interface,
 					   -1);
 
 	g_free (name);
@@ -135,12 +140,6 @@ device_proxy_available_cb (GUPnPControlPoint *cp,
 	GUPnPServiceInfo *info;
 	const gchar *type;
 
-	type = gupnp_device_info_get_device_type (GUPNP_DEVICE_INFO (proxy));
-	if (!g_pattern_match_simple (MEDIA_SERVER, type)) {
-		/* We are only interested in MediaServer */
-		return;
-	}
-
 	info = gupnp_device_info_get_service (GUPNP_DEVICE_INFO (proxy), CDS);
 	if (G_UNLIKELY (info == NULL)) {
 		/* No ContentDirectory implemented? Not interesting. */
@@ -168,32 +167,14 @@ device_proxy_unavailable_cb (GUPnPControlPoint *cp,
 		gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 }
 
-static gboolean
-init (NstPlugin *plugin)
+static void
+on_context_available (GUPnPContextManager *context_manager,
+                      GUPnPContext        *context,
+                      gpointer             user_data)
 {
-	GtkListStore *store;
-	GtkCellRenderer *renderer;
-	GError *error;
-	char *upload_cmd;
+	GUPnPControlPoint *cp;
 
-	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-
-	upload_cmd = g_find_program_in_path ("gupnp-upload");
-	if (upload_cmd == NULL)
-		return FALSE;
-	g_free (upload_cmd);
-
-	error = NULL;
-	context = gupnp_context_new (NULL, NULL, 0, &error);
-	if (error != NULL) {
-		g_error (error->message);
-		g_error_free (error);
-
-		return FALSE;
-	}
-
-	cp = gupnp_control_point_new (context, "ssdp:all");
+	cp = gupnp_control_point_new (context, MEDIA_SERVER);
 
 	g_signal_connect (cp,
 			  "device-proxy-available",
@@ -206,11 +187,37 @@ init (NstPlugin *plugin)
 
 	gssdp_resource_browser_set_active (GSSDP_RESOURCE_BROWSER (cp), TRUE);
 
+	/* Let context manager take care of the control point life cycle */
+	gupnp_context_manager_manage_control_point (context_manager, cp);
+	g_object_unref (cp);
+}
+
+static gboolean
+init (NstPlugin *plugin)
+{
+	GtkListStore *store;
+	GtkCellRenderer *renderer;
+	char *upload_cmd;
+
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
+	upload_cmd = g_find_program_in_path ("gupnp-upload");
+	if (upload_cmd == NULL)
+		return FALSE;
+	g_free (upload_cmd);
+
+	context_manager = gupnp_context_manager_new (NULL, 0);
+	g_assert (context_manager != NULL);
+	g_signal_connect (context_manager, "context-available",
+			  G_CALLBACK (on_context_available), NULL);
+
 	combobox = gtk_combo_box_new ();
 
 	store = gtk_list_store_new (NUM_COLS,
 				    G_TYPE_STRING,   /* UDN  */
-				    G_TYPE_STRING);  /* Name */
+				    G_TYPE_STRING,   /* Name */
+				    G_TYPE_STRING);  /* Network Interface */
 	model = GTK_TREE_MODEL (store);
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combobox), model);
 
@@ -237,7 +244,7 @@ send_files (NstPlugin *plugin,
 	    GtkWidget *contact_widget,
 	    GList *file_list)
 {
-	gchar *upload_cmd, *udn;
+	gchar *upload_cmd, *udn, *interface;
 	GPtrArray *argv;
 	gboolean ret;
 	GList *l;
@@ -247,7 +254,8 @@ send_files (NstPlugin *plugin,
 	if (!gtk_combo_box_get_active_iter (GTK_COMBO_BOX (combobox), &iter))
 		return FALSE;
 
-	gtk_tree_model_get (model, &iter, UDN_COL, &udn, -1);
+	gtk_tree_model_get (model, &iter, UDN_COL, &udn, INTERFACE_COL,
+			    &interface, -1);
 
 	upload_cmd = g_find_program_in_path ("gupnp-upload");
 	if (upload_cmd == NULL)
@@ -257,6 +265,8 @@ send_files (NstPlugin *plugin,
 	g_ptr_array_add (argv, upload_cmd);
 	g_ptr_array_add (argv, "-t");
 	g_ptr_array_add (argv, "15"); /* discovery timeout (seconds) */
+	g_ptr_array_add (argv, "-e");
+	g_ptr_array_add (argv, interface);
 	g_ptr_array_add (argv, udn);
 	for (l = file_list ; l; l=l->next) {
 		gchar *file_path;
@@ -288,8 +298,7 @@ destroy (NstPlugin *plugin)
 	gtk_widget_destroy (combobox);
 	g_object_unref (model);
 
-	g_object_unref (cp);
-	g_object_unref (context);
+	g_object_unref (context_manager);
 
 	return TRUE;
 }
@@ -300,7 +309,7 @@ NstPluginInfo plugin_info = {
 	"upnp",
 	N_("UPnP Media Server"),
 	FALSE,
-	FALSE,
+	NAUTILUS_CAPS_NONE,
 	init,
 	get_contacts_widget,
 	NULL,
